export class myQAccessory {
    // The constructor initializes key variables and calls configureDevice().
    constructor(platform, accessory) {
        this.accessory = accessory;
        this.api = platform.api;
        this.config = platform.config;
        this.hap = this.api.hap;
        this.log = platform.log;
        this.myQ = platform.myQ;
        this.platform = platform;
        this.configureDevice();
    }
    // Execute myQ commands.
    async command(myQCommand) {
        const device = this.accessory.context.device;
        if (!device) {
            this.log.error("%s: Can't find the associated device in the myQ API.", this.name());
            return false;
        }
        // Execute the command.
        await this.myQ.execute(device, myQCommand);
        // Increase the frequency of our polling for state updates to catch any updates from myQ.
        // This will trigger polling at activeRefreshInterval until activeRefreshDuration is hit. If you
        // query the myQ API too quickly, the API won't have had a chance to begin executing our command.
        this.platform.pollOptions.count = 0;
        this.platform.poll(this.config.refreshInterval * -1);
        return true;
    }
    // Configure the device information for HomeKit.
    configureInfo() {
        const device = this.accessory.context.device;
        // Set the firmware revision for this device.
        // Fun fact: This firmware information is stored on the gateway not the device.
        const gwParent = this.myQ.devices.find(x => x.serial_number === device.parent_device_id);
        let gwBrand = "Liftmaster";
        let gwProduct = "myQ";
        if (gwParent?.state?.firmware_version) {
            const gwInfo = this.myQ.getHwInfo(gwParent.serial_number);
            this.accessory
                .getService(this.hap.Service.AccessoryInformation)
                ?.updateCharacteristic(this.hap.Characteristic.FirmwareRevision, gwParent.state.firmware_version);
            // If we're able to lookup hardware information, use it. getHwInfo returns an object containing
            // device type and brand information.
            gwBrand = gwInfo?.brand ?? gwBrand;
            gwProduct = gwInfo?.product ?? gwProduct;
        }
        // Update the manufacturer information for this device.
        this.accessory
            .getService(this.hap.Service.AccessoryInformation)
            ?.updateCharacteristic(this.hap.Characteristic.Manufacturer, gwBrand);
        // Update the model information for this device.
        this.accessory
            .getService(this.hap.Service.AccessoryInformation)
            ?.updateCharacteristic(this.hap.Characteristic.Model, gwProduct);
        // Update the serial number for this device.
        this.accessory
            .getService(this.hap.Service.AccessoryInformation)
            ?.updateCharacteristic(this.hap.Characteristic.SerialNumber, device.serial_number);
        return true;
    }
    // Name utility function.
    name() {
        return this.accessory.displayName ?? this.accessory.context.device.name;
    }
}
//# sourceMappingURL=myq-accessory.js.map